<?php
/*
Plugin Name:    Tour Guide for wProject
Plugin URI:     https://rocketapps.com.au/product/tour-guide/
Description:    Get contextual tips on any page with a single click.
Version:        1.0.1
Author: 		Rocket Apps
Author URI: 	https://rocketapps.com.au
Text Domain: 	wproject-tour-guide
Author Email:   support@rocketapps.com.au
Domain Path:    /languages/
*/

/* Look for translation file. */
function wproject_tour_guide_textdomain() {
    load_plugin_textdomain( 'wproject-tour-guide', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
}
add_action( 'plugins_loaded', 'wproject_tour_guide_textdomain' );

/* Update checker */
require 'plugin-update-checker/plugin-update-checker.php';
$WPTOURUpdateChecker = Puc_v4_Factory::buildUpdateChecker(
    'https://rocketapps.com.au/files/wproject/wproject-tour-guide/info.json',
    __FILE__,
    'wproject-tour-guide'
);

/* CSS */
function tour_css() {
    wp_enqueue_style( 'wproject-tour-guide-css', plugins_url('/css/wproject-tour-guide.css', __FILE__) );
}
add_action( 'wp_enqueue_scripts', 'tour_css' );

/* If user... */
add_action('init','current_user');
function current_user() {

    if(is_user_logged_in()) {

        $user_info  = get_userdata(get_current_user_id());
        $onboarding = $user_info->onboarding;

        /* Only allow work if not a desktop device and if onboarding is complete */
        if(!wp_is_mobile() && $onboarding == 'complete' && ! is_admin()) {

            // if( current_user_can('administrator')) {
            // } 

            function wp_tour() { ?>

                <script>
                    jQuery( document ).ready(function() {

                        jQuery('header .icons').prepend('<li class="toggle-tour"><svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-life-buoy"><circle cx="12" cy="12" r="10"></circle><circle cx="12" cy="12" r="4"></circle><line x1="4.93" y1="4.93" x2="9.17" y2="9.17"></line><line x1="14.83" y1="14.83" x2="19.07" y2="19.07"></line><line x1="14.83" y1="9.17" x2="19.07" y2="4.93"></line><line x1="14.83" y1="9.17" x2="18.36" y2="5.64"></line><line x1="4.93" y1="19.07" x2="9.17" y2="14.83"></line></svg><?php if(!isset($_COOKIE['wproject-tour-guide'])) { ?><span><?php _e('Toggle the lifebuoy on any page to show/hide the contextual tour guide.', 'wproject-tour-guide'); ?><em><?php _e('Got it', 'wproject-tour-guide'); ?></em></span><?php } ?></li>');
                        
                        jQuery('.toggle-tour em').click(function() {
                            var expirationDate = new Date();
                            expirationDate.setFullYear(expirationDate.getFullYear() + 1);
                            Cookies.set('wproject-tour-guide', 'acknowledged', { expires: expirationDate });
                            jQuery('header .toggle-tour span').fadeOut();
                        });

                        function tour_boxes() {

                            jQuery('.toggle-tour').addClass('active');

                            <?php if(is_front_page()) { ?>
                                /* Account */
                                jQuery('body').append('<div class="tour-box arrow-left user-account-tour"><?php _e('Update your details and preferences.', 'wproject-tour-guide'); ?></div>');

                                /* Create */
                                if ( jQuery( '.new' ).length ) {
                                    jQuery('body').append('<div class="tour-box arrow-left create-tour"><?php _e('Create tasks, projects and more, depending on privileges and settings.', 'wproject-tour-guide'); ?></div>');
                                }

                                /* Stats (dashboard) */
                                if ( jQuery( '.stats' ).length) {
                                    jQuery('.stats').before('<div class="tour-box arrow-bottom-centre stats-tour"><?php _e('A quick overview of the entire organisation.', 'wproject-tour-guide'); ?></div>');
                                }

                                /* Projects chart */
                                if ( jQuery( '.projects-chart' ).length ) {
                                    jQuery('.projects-chart').css('position', 'relative');
                                    jQuery('.projects-chart').prepend('<div class="tour-box arrow-bottom-centre projects-chart-tour"><?php _e('Quick access to the projects you manage.', 'wproject-tour-guide'); ?></div>');
                                }

                                /* Dark and light modes */
                                if ( jQuery( '#switch-theme-form' ).length ) {
                                    jQuery('body').append('<div class="tour-box arrow-top-right light-dark-tour"><?php _e('Toggle between light and dark modes', 'wproject-tour-guide'); ?></div>');
                                }

                                /* Dark and light modes */
                                if ( jQuery( '.latest-activity' ).length ) {
                                    jQuery('.latest-activity').css('position', 'relative');
                                    jQuery('.latest-activity').prepend('<div class="tour-box arrow-bottom-centre latest-activity-tour"><?php _e('A list of all recent activity. Edit <a href="/account/">your account</a> to change how many items are shown here.', 'wproject-tour-guide'); ?></div>');
                                }

                                /* Gantt Pro (dashboard) */
                                if ( jQuery( '.gantt-target' ).length) {
                                    jQuery('.gantt-target').prepend('<div class="tour-box arrow-bottom-centre gantt-pro-tour"><?php _e('Change the view of the Gantt chart.', 'wproject-tour-guide'); ?></div>');
                                    jQuery('.gantt-target').prepend('<div class="tour-box arrow-bottom-centre gantt-pro-items-tour"><?php _e('Drag items in the Gantt chart to change start dates, end dates or progress.', 'wproject-tour-guide'); ?></div>');
                                }

                                /* Gantt (dashboard) */
                                if ( jQuery( '.gantt' ).length ) {
                                    jQuery('.gantt').append('<div class="tour-box arrow-bottom-centre gantt-tour"><?php _e('The Gantt chart on this dashboard shows the progress of projects. Control it with with these elements.', 'wproject-tour-guide'); ?></div>');
                                }

                                /* My Projects */
                                if ( jQuery( '.my-projects' ).length ) {
                                    jQuery('.tab-nav').prepend('<div class="tour-box arrow-bottom-centre my-projects-tour"><?php _e('View the projects you are managing.', 'wproject-tour-guide'); ?></div>');
                                }

                                /* All Projects */
                                if ( jQuery( '.projects-list' ).length ) {
                                    jQuery('.projects-list').prepend('<div class="tour-box arrow-top-left all-projects-tour"><?php _e('All projects you have access to or are allowed to see.', 'wproject-tour-guide'); ?></div>');
                                }
                            <?php } else if(is_tax( 'project' )) { ?>

                                /* Gantt Pro (dashboard) */
                                if ( jQuery( '.gantt-target' ).length) {
                                    jQuery('.gantt-target').prepend('<div class="tour-box arrow-left gantt-pro-box-project-tour"><?php _e('Change the view of the Gantt chart.', 'wproject-tour-guide'); ?></div>');
                                }

                                /* Gantt (dashboard) */
                                if ( jQuery( '.gantt' ).length ) {
                                    jQuery('.gantt').append('<div class="tour-box arrow-bottom-centre gantt-tour"><?php _e('The Gantt chart on this dashboard shows the progress of projects. Control it with with these elements.', 'wproject-tour-guide'); ?></div>');
                                }

                                /* Project team */
                                jQuery('.project-team ').prepend('<div class="tour-box arrow-right project-team-tour"><?php _e('Everyone who is involved in this project, including the project manager.', 'wproject-tour-guide'); ?></div>');

                                /* Project progress bar */
                                jQuery('.main-progress').before('<div class="tour-box arrow-bottom-centre project-progress-bar-tour"><?php _e('The progress of the current project (blue) and tasks that are in progress (pink).', 'wproject-tour-guide'); ?></div>');

                                <?php if( !current_user_can('client')) { ?>
                                /* Timer */
                                if ( jQuery( '.task-in-progress' ).length ) {
                                    jQuery('.task-in-progress').prepend('<div class="tour-box arrow-left task-in-progress-tour"><?php _e('The task you are currently recording time on (if any).', 'wproject-tour-guide'); ?></div>');
                                }
                                <?php } ?>

                                <?php if( !current_user_can('client')) { ?>
                                /* Search */
                                jQuery('body').append('<div class="tour-box arrow-left contextual-search-tour"><?php _e('Contextual search will filter the tasks listed below. Alternatively, pressing enter will submit a search query.', 'wproject-tour-guide'); ?></div>');
                                <?php } ?>

                                /* My tasks */
                                if ( jQuery( '.my-tasks' ).length) {
                                    jQuery('.tab-nav').prepend('<div class="tour-box arrow-bottom-centre my-tasks-tour"><?php _e('These are your tasks in this project.', 'wproject-tour-guide'); ?></div>');
                                }

                                /* Other tasks */
                                if ( jQuery( '.other-tasks' ).length) {
                                    jQuery('.tab-nav').prepend('<div class="tour-box arrow-top-centre other-tasks-tour"><?php _e('These tasks are owned by other users in this project.', 'wproject-tour-guide'); ?></div>');
                                }

                                /* Milestones */
                                if ( jQuery( '.all-milestones' ).length && jQuery( '.other-tasks' ).length) {
                                    jQuery('.all-milestones').before('<div class="tour-box arrow-left all-milestones-tour"><?php _e('A list of all milestones in this project, regardless of who is responsible for them.', 'wproject-tour-guide'); ?></div>');
                                }

                                /* Change task status */
                                jQuery('.sort-my-tasks li:first-child .task-status-container').prepend('<div class="tour-box arrow-top-right change-task-status-tour"><?php _e('Change the status of a task. This only applies to tasks that you own.', 'wproject-tour-guide'); ?></div>');

                                /* Kanban */
                                if ( jQuery( '.kanban-container' ).length) {
                                    jQuery('.kanban-container').before('<div class="tour-box arrow-bottom-centre kanban-box-tour"><?php _e('If the setting has been enabled, you can drag cards between columns.', 'wproject-tour-guide'); ?></div>');
                                }
                                
                            <?php } else if(is_singular('task')) { ?>

                                /* Timer */
                                if ( jQuery( '.timer-ui' ).length) {
                                    jQuery('.timer-ui').before('<div class="tour-box arrow-bottom-centre timer-ui-tour"><?php _e('Start record time on this task, or add missed time.', 'wproject-tour-guide'); ?></div>');
                                }

                                /* Change task status (single page) */
                                if ( jQuery( '.change-task-status' ).length) {
                                    jQuery('.side-form').css('position', 'relative');
                                    jQuery('.side-form.change-task-status').prepend('<div class="tour-box arrow-bottom-centre single-task-status-tour"><?php _e('Change the status of this task.', 'wproject-tour-guide'); ?></div>');
                                }

                                /* Task relation */
                                if ( jQuery( '.relation' ).length) {
                                    jQuery('.relation').css('position', 'relative');
                                    jQuery('.relation').prepend('<div class="tour-box arrow-bottom-centre task-relation-tour"><?php _e('Start record time on this task, or add missed time.', 'wproject-tour-guide'); ?></div>');
                                }

                                /* Context label */
                                if ( jQuery( '.context-label' ).length) {
                                    jQuery('.context-label').css('position', 'relative');
                                    jQuery('.context-label').prepend('<div class="tour-box arrow-top-left context-label-tour"><?php _e('A label that provides additional context for this task.', 'wproject-tour-guide'); ?></div>');
                                }

                            <?php } ?>

                            /* Clients */
                            <?php if( current_user_can('client')) { ?>
                                
                                /* Latest tasks */
                                if ( jQuery( '.my-latest-tasks' ).length) {
                                    jQuery('.my-latest-tasks').css('position', 'relative');
                                    jQuery('.tabby').append('<div class="tour-box arrow-left client-my-latest-tasks-tour"><?php _e('These are tasks that belong to you (from any project).', 'wproject-tour-guide'); ?></div>');
                                }

                                <?php if(is_tax( 'project' )) { ?>
                                /* Timer */
                                if ( jQuery( '.task-in-progress' ).length ) {
                                    jQuery('.task-in-progress').prepend('<div class="tour-box arrow-top-right client-task-in-progress-tour"><?php _e('The task you are currently recording time on (if any).', 'wproject-tour-guide'); ?></div>');
                                }
                                <?php } ?>

                            <?php } ?>

                        }

                        function hide_tour_boxes() {
                            jQuery('.tour-box').hide();
                            jQuery('.toggle-tour').removeClass('active');
                        }

                        jQuery(document).on('click', '.toggle-tour', function() {
                            return (this.tog = !this.tog) ? tour_boxes() : hide_tour_boxes();
                        });

                        jQuery(document).on('click', '.tour-box', function() {
                            jQuery(this).fadeOut()
                        });

                    });
                </script>
            <?php }
            add_action( 'wp_footer', 'wp_tour' );
            ?>
            <?php
        }
    }
}